aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/graph/nodes/PoolingLayerNode.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/graph/nodes/PoolingLayerNode.h')
-rw-r--r--arm_compute/graph/nodes/PoolingLayerNode.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/arm_compute/graph/nodes/PoolingLayerNode.h b/arm_compute/graph/nodes/PoolingLayerNode.h
index e250eb247a..d037ea25ab 100644
--- a/arm_compute/graph/nodes/PoolingLayerNode.h
+++ b/arm_compute/graph/nodes/PoolingLayerNode.h
@@ -44,17 +44,16 @@ public:
* @return Pooling Layer info
*/
PoolingLayerInfo pooling_info() const;
/** Computes pooling output shape
*
* @param[in] input_shape Input shape
* @param[in] info Pooling operation attributes
*
- * @return Output shape
+ * @return Output descriptor
*/
- static TensorShape compute_output_shape(TensorShape input_shape, PoolingLayerInfo info);
+ static TensorDescriptor compute_output_descriptor(const TensorDescriptor &input_descriptor, PoolingLayerInfo info);
// Inherited overridden methods:
- Status validate() override;
NodeType type() const override;
bool forward_descriptors() override;
TensorDescriptor configure_output(size_t idx) const override;
@@ -44,17 +44,16 @@ public:
*/
PoolingLayerInfo pooling_info() const;
- /** Computes pooling output shape
+ /** Computes pooling output descriptor
*
@@ -44,17 +44,16 @@ public:
*
- * @param[in] input_shape Input shape
- * @param[in] info Pooling operation attributes
+ * @param[in] input_descriptor Input descriptor
+ * @param[in] info Pooling operation attributes
*